from getDist_for_GAMBIT import *
import matplotlib.pyplot as plt

# Plot labels for the parameters we scanned over.
labels_dict = {
    'H0':r'$H_{0}$',
    'Omega_m':r'$\Omega_\mathrm{m}$',
}


# Include bounds for parameters which will hit the left and/or right edge of the parameter space
bounds_dict = {
    'H0':(50.,100.),
    'Omega_m':(0.0,0.6),
}

logSpace = list()

settings = {
    'fine_bins_2D':512,
    'max_corr_2D':0.0,
    'smooth_scale_2D':-1.0,
    'fine_bins':2096,
    'num_bins':2096,
    'smooth_scale':1,
}

additional_keys = {
    'get_Omega0_m_classy':'Omega_m',
}


hdf5file1 = './BAO_BBN_lya.hdf5'
hdf5file2 = './BAO_BBN_galaxy.hdf5'
hdf5file3 = './BAO_BBN_combined.hdf5'

hdf5file4 = './BAO_BBN_lya_neff.hdf5'
hdf5file5 = './BAO_BBN_galaxy_neff.hdf5'
hdf5file6 = './BAO_BBN_combined_neff.hdf5'


res1 = get_MCSamples_from_gambit(hdf5file1,
                                 sampler='multinest',
                                 logSpace=logSpace,
                                 settings=settings,
                                 group='BAOBNN',
                                 bounds_dict=bounds_dict,
                                 labels_dict=labels_dict,
                                 additional_keys=additional_keys)

res2 = get_MCSamples_from_gambit(hdf5file2,
                                 sampler='multinest',
                                 logSpace=logSpace,
                                 settings=settings,
                                 group='BAOBNN',
                                 bounds_dict=bounds_dict,
                                 labels_dict=labels_dict,
                                 additional_keys=additional_keys)

res3 = get_MCSamples_from_gambit(hdf5file3,
                                 sampler='multinest',
                                 logSpace=logSpace,
                                 settings=settings,
                                 group='BAOBNN',
                                 bounds_dict=bounds_dict,
                                 labels_dict=labels_dict,
                                 additional_keys=additional_keys)

res4 = get_MCSamples_from_gambit(hdf5file4,
                                 sampler='multinest',
                                 logSpace=logSpace,
                                 settings=settings,
                                 group='BAOBNN',
                                 bounds_dict=bounds_dict,
                                 labels_dict=labels_dict,
                                 additional_keys=additional_keys)

res5 = get_MCSamples_from_gambit(hdf5file5,
                                 sampler='multinest',
                                 logSpace=logSpace,
                                 settings=settings,
                                 group='BAOBNN',
                                 bounds_dict=bounds_dict,
                                 labels_dict=labels_dict,
                                 additional_keys=additional_keys)

res6 = get_MCSamples_from_gambit(hdf5file6,
                                 sampler='multinest',
                                 logSpace=logSpace,
                                 settings=settings,
                                 group='BAOBNN',
                                 bounds_dict=bounds_dict,
                                 labels_dict=labels_dict,
                                 additional_keys=additional_keys)


coords1_68 = get_2D_contour_level(res1,0.68,'Omega_m', 'H0')
coords1_95 = get_2D_contour_level(res1,0.95,'Omega_m', 'H0')
coords2_68 = get_2D_contour_level(res2,0.68,'Omega_m', 'H0')
coords2_95 = get_2D_contour_level(res2,0.95,'Omega_m', 'H0')
coords3_68 = get_2D_contour_level(res3,0.68,'Omega_m', 'H0')
coords3_95 = get_2D_contour_level(res3,0.95,'Omega_m', 'H0')

coords4_68 = get_2D_contour_level(res4,0.68,'Omega_m', 'H0')
coords4_95 = get_2D_contour_level(res4,0.95,'Omega_m', 'H0')
coords5_68 = get_2D_contour_level(res5,0.68,'Omega_m', 'H0')
coords5_95 = get_2D_contour_level(res5,0.95,'Omega_m', 'H0')
coords6_68 = get_2D_contour_level(res6,0.68,'Omega_m', 'H0')
coords6_95 = get_2D_contour_level(res6,0.95,'Omega_m', 'H0')


plt.clf()

fig, ax = plt.subplots(figsize=(6.4,4.0))

ax.set_xlim(.0,.6)
#ax.set_ylim(60.,105.)
ax.set_ylim(60.,92.)
ax.set_xlabel(labels_dict.get('Omega_m'))
ax.set_ylabel(labels_dict.get('H0'))

schoeneberg_result_nodNeff = plt.imread('./nonur_gallya_2d_omh_comp_new_solo.png')

ax.imshow(schoeneberg_result_nodNeff,extent=(0.0,0.598,55.,94.4),aspect='auto',interpolation='none')

ax.plot(coords1_68[0],coords1_68[1],ls='solid',c='C2')
ax.plot(coords1_95[0],coords1_95[1],ls='solid',c='C2')
ax.plot(coords2_68[0],coords2_68[1],ls='solid',c='C0')
ax.plot(coords2_95[0],coords2_95[1],ls='solid',c='C0')
ax.plot(coords3_68[0],coords3_68[1],ls='solid',c='C3')
ax.plot(coords3_95[0],coords3_95[1],ls='solid',c='C3')

ax.plot([],[],'C2-',label=r'Ly-$\alpha$ BAO')
ax.plot([],[],'C0-',label=r'Galaxy BAO')
ax.plot([],[],'C3-',label=r'Combination')

ax.plot([],[],'C2-',lw=8, alpha=0.5, label=r'Ly-$\alpha$ BAO, Ref.\,[138]')
ax.plot([],[],'C1-',lw=8, alpha=0.5,label=r'local $H_0$')

ax.text(0.99,1.02, r'\textsf{GAMBIT::CosmoBit}',horizontalalignment='right', verticalalignment='bottom', transform=ax.transAxes, fontsize='large')
ax.text(0.97,0.02, r'$\Delta N_{\rm eff}=0$',horizontalalignment='right', verticalalignment='bottom', transform=ax.transAxes, fontsize=16)


#ax.legend(loc='upper center', ncol=2)
#fig.savefig('./BAO_BBN_nodNeff.pdf')

fig.savefig('./BAO_BBN_nodNeff_noLabel_limits.pdf')


fig, ax = plt.subplots(figsize=(6.4,4.0))

ax.set_xlim(.0,.6)
#ax.set_ylim(55.,95.)
ax.set_ylim(60.,105.)
ax.set_xlabel(labels_dict.get('Omega_m'))
ax.set_ylabel(labels_dict.get('H0'))

schoeneberg_result_wdNeff = plt.imread('./gallya_2d_omh_comp_new_solo.png')

ax.imshow(schoeneberg_result_wdNeff,extent=(0.0,0.599,55.,95.),aspect='auto',interpolation='none')

ax.plot(coords4_68[0],coords4_68[1],ls='solid',c='C2')
ax.plot(coords4_95[0],coords4_95[1],ls='solid',c='C2')
ax.plot(coords5_68[0],coords5_68[1],ls='solid',c='C0')
ax.plot(coords5_95[0],coords5_95[1],ls='solid',c='C0')
ax.plot(coords6_68[0],coords6_68[1],ls='solid',c='C3')
ax.plot(coords6_95[0],coords6_95[1],ls='solid',c='C3')

ax.plot([],[],'C2-',label=r'BBN+Ly-$\alpha$ BAO')
ax.plot([],[],'C0-',label=r'BBN+Galaxy BAO')
ax.plot([],[],'C3-',label=r'Combination')

ax.plot([],[],'C2-',lw=8, alpha=0.5, label=r"BBN+Ly-$\alpha$ BAO, from")
ax.plot([],[], color='white',lw=8, alpha=0.5, label=r"Sch\"oneberg \emph{et al.} `19")
ax.plot([],[],'C1-',lw=8, alpha=0.5,label=r'local $H_0$')

ax.text(0.99,1.02, r'\textsf{GAMBIT::CosmoBit}',horizontalalignment='right', verticalalignment='bottom', transform=ax.transAxes, fontsize='large')

ax.legend(loc='upper center', ncol=2, fontsize=13)
fig.savefig('./BAO_BBN_dNeff.pdf')
